#line 1 "fontanvil/feascan.c"
/* GENERATED FILE.  EDIT THE SOURCE IN feascan.l INSTEAD! */

#line 4 "fontanvil/feascan.c"

#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

#define yy_create_buffer feascan_create_buffer
#define yy_delete_buffer feascan_delete_buffer
#define yy_scan_buffer feascan_scan_buffer
#define yy_scan_string feascan_scan_string
#define yy_scan_bytes feascan_scan_bytes
#define yy_init_buffer feascan_init_buffer
#define yy_flush_buffer feascan_flush_buffer
#define yy_load_buffer_state feascan_load_buffer_state
#define yy_switch_to_buffer feascan_switch_to_buffer
#define yypush_buffer_state feascanpush_buffer_state
#define yypop_buffer_state feascanpop_buffer_state
#define yyensure_buffer_stack feascanensure_buffer_stack
#define yy_flex_debug feascan_flex_debug
#define yyin feascanin
#define yyleng feascanleng
#define yylex feascanlex
#define yylineno feascanlineno
#define yyout feascanout
#define yyrestart feascanrestart
#define yytext feascantext
#define yywrap feascanwrap
#define yyalloc feascanalloc
#define yyrealloc feascanrealloc
#define yyfree feascanfree

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 6
#define YY_FLEX_SUBMINOR_VERSION 4
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

#ifdef yy_create_buffer
#define feascan_create_buffer_ALREADY_DEFINED
#else
#define yy_create_buffer feascan_create_buffer
#endif

#ifdef yy_delete_buffer
#define feascan_delete_buffer_ALREADY_DEFINED
#else
#define yy_delete_buffer feascan_delete_buffer
#endif

#ifdef yy_scan_buffer
#define feascan_scan_buffer_ALREADY_DEFINED
#else
#define yy_scan_buffer feascan_scan_buffer
#endif

#ifdef yy_scan_string
#define feascan_scan_string_ALREADY_DEFINED
#else
#define yy_scan_string feascan_scan_string
#endif

#ifdef yy_scan_bytes
#define feascan_scan_bytes_ALREADY_DEFINED
#else
#define yy_scan_bytes feascan_scan_bytes
#endif

#ifdef yy_init_buffer
#define feascan_init_buffer_ALREADY_DEFINED
#else
#define yy_init_buffer feascan_init_buffer
#endif

#ifdef yy_flush_buffer
#define feascan_flush_buffer_ALREADY_DEFINED
#else
#define yy_flush_buffer feascan_flush_buffer
#endif

#ifdef yy_load_buffer_state
#define feascan_load_buffer_state_ALREADY_DEFINED
#else
#define yy_load_buffer_state feascan_load_buffer_state
#endif

#ifdef yy_switch_to_buffer
#define feascan_switch_to_buffer_ALREADY_DEFINED
#else
#define yy_switch_to_buffer feascan_switch_to_buffer
#endif

#ifdef yypush_buffer_state
#define feascanpush_buffer_state_ALREADY_DEFINED
#else
#define yypush_buffer_state feascanpush_buffer_state
#endif

#ifdef yypop_buffer_state
#define feascanpop_buffer_state_ALREADY_DEFINED
#else
#define yypop_buffer_state feascanpop_buffer_state
#endif

#ifdef yyensure_buffer_stack
#define feascanensure_buffer_stack_ALREADY_DEFINED
#else
#define yyensure_buffer_stack feascanensure_buffer_stack
#endif

#ifdef yylex
#define feascanlex_ALREADY_DEFINED
#else
#define yylex feascanlex
#endif

#ifdef yyrestart
#define feascanrestart_ALREADY_DEFINED
#else
#define yyrestart feascanrestart
#endif

#ifdef yylex_init
#define feascanlex_init_ALREADY_DEFINED
#else
#define yylex_init feascanlex_init
#endif

#ifdef yylex_init_extra
#define feascanlex_init_extra_ALREADY_DEFINED
#else
#define yylex_init_extra feascanlex_init_extra
#endif

#ifdef yylex_destroy
#define feascanlex_destroy_ALREADY_DEFINED
#else
#define yylex_destroy feascanlex_destroy
#endif

#ifdef yyget_debug
#define feascanget_debug_ALREADY_DEFINED
#else
#define yyget_debug feascanget_debug
#endif

#ifdef yyset_debug
#define feascanset_debug_ALREADY_DEFINED
#else
#define yyset_debug feascanset_debug
#endif

#ifdef yyget_extra
#define feascanget_extra_ALREADY_DEFINED
#else
#define yyget_extra feascanget_extra
#endif

#ifdef yyset_extra
#define feascanset_extra_ALREADY_DEFINED
#else
#define yyset_extra feascanset_extra
#endif

#ifdef yyget_in
#define feascanget_in_ALREADY_DEFINED
#else
#define yyget_in feascanget_in
#endif

#ifdef yyset_in
#define feascanset_in_ALREADY_DEFINED
#else
#define yyset_in feascanset_in
#endif

#ifdef yyget_out
#define feascanget_out_ALREADY_DEFINED
#else
#define yyget_out feascanget_out
#endif

#ifdef yyset_out
#define feascanset_out_ALREADY_DEFINED
#else
#define yyset_out feascanset_out
#endif

#ifdef yyget_leng
#define feascanget_leng_ALREADY_DEFINED
#else
#define yyget_leng feascanget_leng
#endif

#ifdef yyget_text
#define feascanget_text_ALREADY_DEFINED
#else
#define yyget_text feascanget_text
#endif

#ifdef yyget_lineno
#define feascanget_lineno_ALREADY_DEFINED
#else
#define yyget_lineno feascanget_lineno
#endif

#ifdef yyset_lineno
#define feascanset_lineno_ALREADY_DEFINED
#else
#define yyset_lineno feascanset_lineno
#endif

#ifdef yywrap
#define feascanwrap_ALREADY_DEFINED
#else
#define yywrap feascanwrap
#endif

#ifdef yyalloc
#define feascanalloc_ALREADY_DEFINED
#else
#define yyalloc feascanalloc
#endif

#ifdef yyrealloc
#define feascanrealloc_ALREADY_DEFINED
#else
#define yyrealloc feascanrealloc
#endif

#ifdef yyfree
#define feascanfree_ALREADY_DEFINED
#else
#define yyfree feascanfree
#endif

#ifdef yytext
#define feascantext_ALREADY_DEFINED
#else
#define yytext feascantext
#endif

#ifdef yyleng
#define feascanleng_ALREADY_DEFINED
#else
#define yyleng feascanleng
#endif

#ifdef yyin
#define feascanin_ALREADY_DEFINED
#else
#define yyin feascanin
#endif

#ifdef yyout
#define feascanout_ALREADY_DEFINED
#else
#define yyout feascanout
#endif

#ifdef yy_flex_debug
#define feascan_flex_debug_ALREADY_DEFINED
#else
#define yy_flex_debug feascan_flex_debug
#endif

#ifdef yylineno
#define feascanlineno_ALREADY_DEFINED
#else
#define yylineno feascanlineno
#endif

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>

/* end standard C headers. */

/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L

/* C99 says to define __STDC_LIMIT_MACROS before including stdint.h,
 * if you want the limit (max/min) macros for int types. 
 */
#ifndef __STDC_LIMIT_MACROS
#define __STDC_LIMIT_MACROS 1
#endif

#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#ifndef SIZE_MAX
#define SIZE_MAX               (~(size_t)0)
#endif

#endif /* ! C99 */

#endif /* ! FLEXINT_H */

/* begin standard C++ headers. */

/* TODO: this is always defined, so inline it */
#define yyconst const

#if defined(__GNUC__) && __GNUC__ >= 3
#define yynoreturn __attribute__((__noreturn__))
#else
#define yynoreturn
#endif

/* Returned upon end-of-file. */
#define YY_NULL 0

/* Promotes a possibly negative, possibly signed char to an
 *   integer in range [0..255] for use as an array index.
 */
#define YY_SC_TO_UI(c) ((YY_CHAR) (c))

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN (yy_start) = 1 + 2 *
/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START (((yy_start) - 1) / 2)
#define YYSTATE YY_START
/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)
/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE yyrestart( yyin  )
#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k.
 * Moreover, YY_BUF_SIZE is 2*YY_READ_BUF_SIZE in the general case.
 * Ditto for the __ia64__ case accordingly.
 */
#define YY_BUF_SIZE 32768
#else
#define YY_BUF_SIZE 16384
#endif /* __ia64__ */
#endif

/* The state buf must be large enough to hold one state per character in the main buffer.
 */
#define YY_STATE_BUF_SIZE   ((YY_BUF_SIZE + 2) * sizeof(yy_state_type))

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef size_t yy_size_t;
#endif

extern int yyleng;

extern FILE *yyin, *yyout;

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2
    
    #define YY_LESS_LINENO(n)
    #define YY_LINENO_REWIND_TO(ptr)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		*yy_cp = (yy_hold_char); \
		YY_RESTORE_YY_MORE_OFFSET \
		(yy_c_buf_p) = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up yytext again */ \
		} \
	while ( 0 )
#define unput(c) yyunput( c, (yytext_ptr)  )

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
	{
	FILE *yy_input_file;

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	int yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	int yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */

	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via yyrestart()), so that the user can continue scanning by
	 * just pointing yyin at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* Stack of input buffers. */
static size_t yy_buffer_stack_top = 0; /**< index of top of stack. */
static size_t yy_buffer_stack_max = 0; /**< capacity of stack. */
static YY_BUFFER_STATE * yy_buffer_stack = NULL; /**< Stack as an array. */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( (yy_buffer_stack) \
                          ? (yy_buffer_stack)[(yy_buffer_stack_top)] \
                          : NULL)
/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE (yy_buffer_stack)[(yy_buffer_stack_top)]

/* yy_hold_char holds the character lost when yytext is formed. */
static char yy_hold_char;
static int yy_n_chars;		/* number of characters read into yy_ch_buf */
int yyleng;

/* Points to current character in buffer. */
static char *yy_c_buf_p = NULL;
static int yy_init = 0;		/* whether we need to initialize */
static int yy_start = 0;	/* start state number */

/* Flag which is used to allow yywrap()'s to do buffer switches
 * instead of setting up a fresh yyin.  A bit of a hack ...
 */
static int yy_did_buffer_switch_on_eof;

void yyrestart ( FILE *input_file  );
void yy_switch_to_buffer ( YY_BUFFER_STATE new_buffer  );
YY_BUFFER_STATE yy_create_buffer ( FILE *file, int size  );
void yy_delete_buffer ( YY_BUFFER_STATE b  );
void yy_flush_buffer ( YY_BUFFER_STATE b  );
void yypush_buffer_state ( YY_BUFFER_STATE new_buffer  );
void yypop_buffer_state ( void );

static void yyensure_buffer_stack ( void );
static void yy_load_buffer_state ( void );
static void yy_init_buffer ( YY_BUFFER_STATE b, FILE *file  );
#define YY_FLUSH_BUFFER yy_flush_buffer( YY_CURRENT_BUFFER )

YY_BUFFER_STATE yy_scan_buffer ( char *base, yy_size_t size  );
YY_BUFFER_STATE yy_scan_string ( const char *yy_str  );
YY_BUFFER_STATE yy_scan_bytes ( const char *bytes, int len  );

void *yyalloc ( yy_size_t  );
void *yyrealloc ( void *, yy_size_t  );
void yyfree ( void *  );

#define yy_new_buffer yy_create_buffer
#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer( yyin, YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
	}
#define yy_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer( yyin, YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
	}
#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

#define feascanwrap() (/*CONSTCOND*/1)
#define YY_SKIP_YYWRAP
typedef flex_uint8_t YY_CHAR;

FILE *yyin = NULL, *yyout = NULL;

typedef int yy_state_type;

extern int yylineno;
int yylineno = 1;

extern char *yytext;
#ifdef yytext_ptr
#undef yytext_ptr
#endif
#define yytext_ptr yytext

static yy_state_type yy_get_previous_state ( void );
static yy_state_type yy_try_NUL_trans ( yy_state_type current_state  );
static int yy_get_next_buffer ( void );
static void yynoreturn yy_fatal_error ( const char* msg  );

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up yytext.
 */
#define YY_DO_BEFORE_ACTION \
	(yytext_ptr) = yy_bp; \
	yyleng = (int) (yy_cp - yy_bp); \
	(yy_hold_char) = *yy_cp; \
	*yy_cp = '\0'; \
	(yy_c_buf_p) = yy_cp;
#define YY_NUM_RULES 64
#define YY_END_OF_BUFFER 65
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct yy_trans_info
	{
	flex_int32_t yy_verify;
	flex_int32_t yy_nxt;
	};
static const flex_int16_t yy_accept[404] =
    {   0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
       65,   63,    7,    6,    6,   62,   63,   63,   62,   60,
       61,   61,   61,   61,   61,   61,   61,   61,   61,   61,
       61,   61,   61,   61,   61,   61,   61,   61,   61,   61,
       61,   61,   61,   61,   63,   62,   58,   58,   61,   63,
       62,   60,    4,    2,    2,    3,    4,    7,    6,    0,
        5,    5,   60,   61,   60,   61,   61,   61,   61,   61,
       61,   61,   61,   11,   61,   61,   61,   61,   61,   61,
       61,   61,   61,   61,   61,   61,   61,   61,   61,   61,
       61,   61,   61,   61,   61,   61,   61,   61,   58,   58,

       58,   58,   60,   61,   60,    2,    4,    1,    5,    0,
       61,   61,   61,   61,   61,   61,   61,   61,   61,   61,
       61,   61,   61,   61,   61,   61,   61,   61,   61,   61,
       61,   61,   61,   61,   54,   61,   61,   61,   61,   53,
       61,   61,   61,    0,   59,    1,   61,   61,   61,   32,
       61,   61,   61,   57,   49,   61,   61,   61,   61,   56,
       61,   61,   19,   61,   61,   61,   61,   61,   61,   30,
       61,   61,   61,   61,   61,   55,   61,   61,   61,   61,
       61,   61,   59,    1,   61,   61,   61,   61,   61,   61,
       12,   61,   61,   61,   61,   61,   61,   61,   61,   61,

       61,   61,   61,   61,   61,   61,   61,   61,   61,   61,
       61,   61,   40,   61,   61,    1,   61,   61,   61,   61,
        9,   61,   61,   61,   14,   61,   61,   61,   20,   61,
       61,   61,   61,   28,   61,   31,   61,   61,   61,   61,
       37,   61,   61,   61,   61,   61,   61,   61,   61,   61,
       61,   61,   61,   61,   13,   61,   61,   18,   61,   61,
       61,   61,   61,   61,   61,   61,   61,   61,   61,   61,
       61,   61,   61,   61,   61,   61,   61,   61,   61,   61,
       61,   61,   61,   61,   61,    0,    0,   61,   61,   26,
       61,   50,   61,   61,   61,   34,   35,   61,   61,   39,

       61,   61,   61,   61,   61,   61,   61,   61,   42,   10,
       61,   15,   61,   61,   61,    0,    0,   61,   61,   61,
       61,   61,   48,   61,   61,   61,   61,   61,   61,   61,
       61,   61,   61,   61,   61,   61,   61,   61,    0,    8,
       61,   61,   61,   61,   29,   33,   47,   38,   61,   61,
       61,   61,   23,   61,   36,   61,   61,   16,   61,   61,
       24,   61,   61,   61,   61,   61,   61,   61,   61,   61,
       44,   17,   52,   25,   61,   51,   41,   61,   61,   61,
       61,   61,   61,   61,   61,   61,   61,   61,   27,   43,
       61,   22,   61,   61,   21,   61,   61,   61,   61,   45,

       61,   46,    0
    } ;

static const YY_CHAR yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    3,
        1,    1,    4,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    2,    1,    5,    6,    1,    1,    1,    7,    8,
        9,    1,   10,    7,   11,   12,   13,   14,   14,   15,
       14,   14,   14,   14,   14,   14,   14,    1,    7,    7,
        7,    7,    1,   16,   17,   18,   19,   20,   21,   22,
       23,   24,   25,   24,   24,   26,   27,   28,   29,   24,
       24,   30,   31,   32,   33,   24,   24,   34,   24,   24,
        7,   35,    7,    1,   36,    1,   37,   38,   39,   40,

       41,   42,   43,   44,   45,   24,   46,   47,   48,   49,
       50,   51,   52,   53,   54,   55,   56,   57,   24,   58,
       59,   24,    7,    1,    7,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,

        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1
    } ;

static const YY_CHAR yy_meta[60] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    1,
        1,    3,    1,    4,    4,    1,    4,    4,    4,    4,
        4,    4,    3,    3,    3,    3,    3,    3,    3,    3,
        3,    3,    3,    5,    1,    3,    4,    4,    4,    4,
        4,    4,    3,    3,    3,    3,    3,    3,    3,    3,
        3,    3,    3,    3,    3,    3,    3,    5,    3
    } ;

static const flex_int16_t yy_base[414] =
    {   0,
        0,   35,   46,    0,   94,    0,    6,    8,   21,   27,
      530,  531,  527,  531,  525,  531,   24,   19,   37,   39,
        0,  496,   43,  483,  488,  491,  478,  468,  472,   18,
       22,  479,   11,   22,   18,   73,  482,  481,   31,   65,
       26,  480,  462,  478,   75,  106,  139,  110,    0,  112,
      123,  127,  531,  531,  511,  531,  184,  511,  531,  140,
      531,  142,  133,    0,  135,  499,  462,  457,  483,  465,
      466,   57,  452,    0,  452,  455,  450,  445,  445,  461,
      462,  448,  448,  457,  446,  451,  443,  439,  443,  437,
      435,   65,  432,  434,  448,  447,  443,  436,  148,    0,

        0,  150,  154,  156,  160,  531,  531,    0,  531,  467,
      431,  434,  453,  434,  450,  432,  426,  433,  432,  417,
      417,  425,  421,  421,  412,  418,  415,  417,  420,   61,
      416,  415,  419,  422,  413,  401,  415,  417,  409,  128,
      406,  431,  395,  170,  172,    0,  531,  397,  432,    0,
      393,  410,  396,  386,    0,  389,  393,  397,  402,  399,
      383,  382,    0,  384,  380,  379,  384,  378,  376,  412,
      385,  381,  373,  382,  373,    0,  374,  369,  386,  381,
      363,  379,  174,    0,  378,  363,  385,  363,  362,  366,
        0,  357,  355,  370,  357,  369,  355,  366,  366,  368,

      356,  347,  351,  354,  360,  358,  353,  344,  342,  340,
      349,  355,    0,  337,  361,  531,  182,  335,  339,  342,
      367,  336,  332,  343,    0,  346,  341,  340,    0,  339,
      336,  327,  324,  334,  338,    0,  319,  323,  331,  330,
        0,  315,  322,  327,  326,  329,  320,  327,  326,  336,
      339,  319,  303,  307,    0,  302,  131,  328,  208,  314,
      304,  312,  305,  297,  309,  300,  308,  293,  290,  304,
      295,  304,  288,  298,  287,  300,  297,  292,  294,  281,
      284,  292,  310,  291,  293,  188,  327,  306,  287,  272,
      276,    0,  287,  269,  269,    0,    0,  265,  265,    0,

      265,  268,  276,  279,  269,  270,  271,  265,    0,    0,
      266,    0,  284,  267,  260,  205,  305,  280,  263,  245,
      262,  259,    0,  247,  262,  258,  253,  244,  273,  240,
      240,  245,  237,  236,  241,  257,  241,  246,  209,  531,
      254,  238,  230,  234,    0,    0,    0,    0,  232,  241,
      233,  223,    0,  237,    0,  236,  221,    0,  220,  217,
        0,  188,  187,  186,  191,  219,  179,  184,  187,  182,
        0,    0,    0,    0,  193,    0,    0,  192,  181,  190,
      175,  184,  179,  178,  175,  163,  183,  164,    0,    0,
      158,    0,  136,  151,    0,  142,  161,  150,  114,    0,

       85,    0,  531,  244,  249,  254,  257,  259,  264,  126,
       88,   62,  269
    } ;

static const flex_int16_t yy_def[414] =
    {   0,
      404,  404,    2,    3,    2,    5,    2,    2,  405,  405,
      403,  403,  403,  403,  403,  403,  406,  403,  403,  407,
      407,  407,  407,  407,  407,  407,  407,  407,  407,  407,
      407,  407,  407,  407,  407,  407,  407,  407,  407,  407,
      407,  407,  407,  407,  408,  408,  407,   47,   47,  403,
      403,  407,  403,  403,  403,  403,  409,  403,  403,  406,
      403,  406,  403,  407,  407,  407,  407,  407,  407,  407,
      407,  407,  407,  407,  407,  407,  407,  407,  407,  407,
      407,  407,  407,  407,  407,  407,  407,  407,  407,  407,
      407,  407,  407,  407,  407,  407,  407,  407,  408,  408,

       47,   47,  403,  407,  407,  403,  403,  410,  403,  403,
      407,  407,  407,  407,  407,  407,  407,  407,  407,  407,
      407,  407,  407,  407,  407,  407,  407,  407,  407,  407,
      407,  407,  407,  407,  407,  407,  407,  407,  407,  407,
      407,  407,  407,  403,  407,  411,  403,  407,  407,  407,
      407,  407,  407,  407,  407,  407,  407,  407,  407,  407,
      407,  407,  407,  407,  407,  407,  407,  407,  407,  407,
      407,  407,  407,  407,  407,  407,  407,  407,  407,  407,
      407,  407,  403,  412,  407,  407,  407,  407,  407,  407,
      407,  407,  407,  407,  407,  407,  407,  407,  407,  407,

      407,  407,  407,  407,  407,  407,  407,  407,  407,  407,
      407,  407,  407,  407,  407,  403,  407,  407,  407,  407,
      407,  407,  407,  407,  407,  407,  407,  407,  407,  407,
      407,  407,  407,  407,  407,  407,  407,  407,  407,  407,
      407,  407,  407,  407,  407,  407,  407,  407,  407,  407,
      407,  407,  407,  407,  407,  407,  407,  407,  407,  407,
      407,  407,  407,  407,  407,  407,  407,  407,  407,  407,
      407,  407,  407,  407,  407,  407,  407,  407,  407,  407,
      407,  407,  407,  407,  407,  403,  413,  407,  407,  407,
      407,  407,  407,  407,  407,  407,  407,  407,  407,  407,

      407,  407,  407,  407,  407,  407,  407,  407,  407,  407,
      407,  407,  407,  407,  407,  413,  413,  407,  407,  407,
      407,  407,  407,  407,  407,  407,  407,  407,  407,  407,
      407,  407,  407,  407,  407,  407,  407,  407,  403,  403,
      407,  407,  407,  407,  407,  407,  407,  407,  407,  407,
      407,  407,  407,  407,  407,  407,  407,  407,  407,  407,
      407,  407,  407,  407,  407,  407,  407,  407,  407,  407,
      407,  407,  407,  407,  407,  407,  407,  407,  407,  407,
      407,  407,  407,  407,  407,  407,  407,  407,  407,  407,
      407,  407,  407,  407,  407,  407,  407,  407,  407,  407,

      407,  407,    0,  403,  403,  403,  403,  403,  403,  403,
      403,  403,  403
    } ;

static const flex_int16_t yy_nxt[591] =
    {   0,
       12,   13,   14,   15,   16,   17,   16,   16,   16,   18,
       19,   12,   12,   20,   20,   50,   51,   50,   51,   52,
       52,   52,   52,   54,   55,   56,   61,   62,   22,   54,
       55,   56,   63,   63,   23,   12,   13,   14,   15,   16,
       17,   16,   16,   16,   18,   19,   12,   12,   20,   20,
       63,   63,   65,   65,   73,   57,   65,   65,   75,   79,
       83,   57,   81,   22,   94,  216,   84,   90,   80,   23,
       24,   76,   25,   26,   82,   27,   74,   77,   28,  167,
       91,   95,   29,   30,   31,   32,   33,   34,   99,   99,
       35,  184,   36,   37,   38,  116,   39,  168,   40,   41,

       42,   43,   44,   45,   46,   92,  117,   47,   47,   85,
       48,   48,   48,   48,   48,   48,  136,   86,   93,   99,
       99,  137,   87,  102,  102,  103,  103,   48,   49,  146,
       48,   48,   48,   48,   48,   48,  103,  103,  104,  402,
      105,  105,   61,   62,  109,   62,   63,   63,   65,   65,
      283,   48,  101,  101,  401,  102,  102,  102,  102,  102,
      102,   99,   99,  102,  102,  144,  284,  103,  103,  145,
      145,  104,  102,  105,  105,  102,  102,  102,  102,  102,
      102,  178,  179,  183,  183,  145,  145,  183,  183,  286,
      400,  399,  398,  397,  396,  287,  102,  108,  108,  246,

      108,  108,  108,  108,  108,  108,  339,  247,  248,  286,
      339,  395,  394,  340,  393,  287,  392,  340,  391,  390,
      108,  108,  108,  108,  108,  108,  389,  288,  388,  387,
      386,  385,  384,  383,  382,  381,  380,  379,  378,  377,
      376,  375,  374,  289,   21,   21,   21,   21,   21,   53,
       53,   53,   53,   53,   60,   60,   60,   60,   60,   64,
       64,   64,  100,  100,  107,  107,  107,  107,  107,  316,
      373,  316,  316,  316,  372,  371,  370,  369,  368,  367,
      366,  365,  364,  363,  362,  361,  360,  359,  358,  357,
      356,  355,  354,  353,  352,  351,  350,  349,  348,  347,

      346,  345,  344,  343,  342,  341,  317,  338,  337,  336,
      335,  334,  333,  332,  331,  330,  329,  328,  327,  326,
      325,  324,  323,  322,  321,  320,  319,  318,  317,  315,
      314,  313,  312,  311,  310,  309,  308,  307,  306,  305,
      304,  303,  302,  301,  300,  299,  298,  297,  296,  295,
      294,  293,  292,  291,  290,  285,  282,  281,  280,  279,
      278,  277,  276,  275,  274,  273,  272,  271,  270,  269,
      268,  267,  266,  265,  264,  263,  262,  261,  260,  259,
      258,  257,  256,  255,  254,  253,  252,  251,  250,  249,
      245,  244,  243,  242,  241,  240,  239,  238,  237,  236,

      235,  234,  233,  232,  231,  230,  229,  228,  227,  226,
      225,  224,  223,  222,  221,  220,  219,  218,  217,  215,
      214,  213,  212,  211,  210,  209,  208,  207,  206,  205,
      204,  203,  202,  201,  200,  199,  198,  197,  196,  195,
      194,  193,  192,  191,  190,  189,  188,  187,  186,  185,
      182,  181,  180,  177,  176,  175,  174,  173,  172,  171,
      170,  169,  166,  165,  164,  163,  162,  161,  160,  159,
      158,  157,  156,  155,  154,  153,  152,  151,  150,  149,
      148,  147,  143,  142,  141,  140,  139,  138,  135,  134,
      133,  132,  131,  130,  129,  128,  127,  126,  125,  124,

      123,  122,  121,  120,  119,  118,  115,  114,  113,  112,
      111,  110,   58,  106,   98,   97,   96,   89,   88,   78,
       72,   71,   70,   69,   68,   67,   66,   59,   58,  403,
       11,  403,  403,  403,  403,  403,  403,  403,  403,  403,
      403,  403,  403,  403,  403,  403,  403,  403,  403,  403,
      403,  403,  403,  403,  403,  403,  403,  403,  403,  403,
      403,  403,  403,  403,  403,  403,  403,  403,  403,  403,
      403,  403,  403,  403,  403,  403,  403,  403,  403,  403,
      403,  403,  403,  403,  403,  403,  403,  403,  403,  403
    } ;

static const flex_int16_t yy_chk[591] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    7,    7,    8,    8,    7,
        7,    8,    8,    9,    9,    9,   17,   17,    1,   10,
       10,   10,   18,   18,    1,    2,    2,    2,    2,    2,
        2,    2,    2,    2,    2,    2,    2,    2,    2,    2,
       19,   19,   20,   20,   30,    9,   23,   23,   31,   33,
       35,   10,   34,    2,   41,  412,   35,   39,   33,    2,
        3,   31,    3,    3,   34,    3,   30,   31,    3,  130,
       39,   41,    3,    3,    3,    3,    3,    3,   45,   45,
        3,  411,    3,    3,    3,   72,    3,  130,    3,    3,

        3,    3,    3,    5,    5,   40,   72,    5,    5,   36,
        5,    5,    5,    5,    5,    5,   92,   36,   40,   46,
       46,   92,   36,   48,   48,   50,   50,    5,    5,  410,
        5,    5,    5,    5,    5,    5,   51,   51,   52,  401,
       52,   52,   60,   60,   62,   62,   63,   63,   65,   65,
      257,    5,   47,   47,  399,   47,   47,   47,   47,   47,
       47,   99,   99,  102,  102,  103,  257,  103,  103,  104,
      104,  105,   47,  105,  105,   47,   47,   47,   47,   47,
       47,  140,  140,  144,  144,  145,  145,  183,  183,  286,
      398,  397,  396,  394,  393,  286,   47,   57,   57,  217,

       57,   57,   57,   57,   57,   57,  316,  217,  217,  259,
      339,  391,  388,  316,  387,  259,  386,  339,  385,  384,
       57,   57,   57,   57,   57,   57,  383,  259,  382,  381,
      380,  379,  378,  375,  370,  369,  368,  367,  366,  365,
      364,  363,  362,  259,  404,  404,  404,  404,  404,  405,
      405,  405,  405,  405,  406,  406,  406,  406,  406,  407,
      407,  407,  408,  408,  409,  409,  409,  409,  409,  413,
      360,  413,  413,  413,  359,  357,  356,  354,  352,  351,
      350,  349,  344,  343,  342,  341,  338,  337,  336,  335,
      334,  333,  332,  331,  330,  329,  328,  327,  326,  325,

      324,  322,  321,  320,  319,  318,  317,  315,  314,  313,
      311,  308,  307,  306,  305,  304,  303,  302,  301,  299,
      298,  295,  294,  293,  291,  290,  289,  288,  287,  285,
      284,  283,  282,  281,  280,  279,  278,  277,  276,  275,
      274,  273,  272,  271,  270,  269,  268,  267,  266,  265,
      264,  263,  262,  261,  260,  258,  256,  254,  253,  252,
      251,  250,  249,  248,  247,  246,  245,  244,  243,  242,
      240,  239,  238,  237,  235,  234,  233,  232,  231,  230,
      228,  227,  226,  224,  223,  222,  221,  220,  219,  218,
      215,  214,  212,  211,  210,  209,  208,  207,  206,  205,

      204,  203,  202,  201,  200,  199,  198,  197,  196,  195,
      194,  193,  192,  190,  189,  188,  187,  186,  185,  182,
      181,  180,  179,  178,  177,  175,  174,  173,  172,  171,
      170,  169,  168,  167,  166,  165,  164,  162,  161,  160,
      159,  158,  157,  156,  154,  153,  152,  151,  149,  148,
      143,  142,  141,  139,  138,  137,  136,  135,  134,  133,
      132,  131,  129,  128,  127,  126,  125,  124,  123,  122,
      121,  120,  119,  118,  117,  116,  115,  114,  113,  112,
      111,  110,   98,   97,   96,   95,   94,   93,   91,   90,
       89,   88,   87,   86,   85,   84,   83,   82,   81,   80,

       79,   78,   77,   76,   75,   73,   71,   70,   69,   68,
       67,   66,   58,   55,   44,   43,   42,   38,   37,   32,
       29,   28,   27,   26,   25,   24,   22,   15,   13,   11,
      403,  403,  403,  403,  403,  403,  403,  403,  403,  403,
      403,  403,  403,  403,  403,  403,  403,  403,  403,  403,
      403,  403,  403,  403,  403,  403,  403,  403,  403,  403,
      403,  403,  403,  403,  403,  403,  403,  403,  403,  403,
      403,  403,  403,  403,  403,  403,  403,  403,  403,  403,
      403,  403,  403,  403,  403,  403,  403,  403,  403,  403
    } ;

static yy_state_type yy_last_accepting_state;
static char *yy_last_accepting_cpos;

extern int yy_flex_debug;
int yy_flex_debug = 0;

/* The intent behind this definition is that it'll catch
 * any uses of REJECT which flex missed.
 */
#define REJECT reject_used_but_not_detected
#define yymore() yymore_used_but_not_detected
#define YY_MORE_ADJ 0
#define YY_RESTORE_YY_MORE_OFFSET
char *yytext;
#line 1 "fontanvil/feascan.l"
/* $Id: feascan.l 9066 2021-06-25 22:58:50Z mskala $ */
/*
 * Tokenizer for Adobe-style feature files
 * Copyright (C) 2015, 2021  Matthew Skala
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Matthew Skala
 * http://ansuz.sooke.bc.ca/
 * mskala@ansuz.sooke.bc.ca
 */
#line 24 "fontanvil/feascan.l"

#include <math.h>
#include <string.h>

#include "fontanvil.h"
#include "gfile.h"
#include "ustring.h"
#include "feascan.h"

#define YY_DECL void fea_ParseTok(struct parseState *tok,TOKENIZER_MODE tm)
   
static struct parseState *gtok;

/* FIXME it'd be nice to make this do better buffering */
#define YY_INPUT(buf,result,max_size) \
   { int ch=agetc(gtok->inlist[gtok->inc_depth]); \
      result=(ch<0)?YY_NULL:(buf[0]=ch,1); }

#line 1007 "fontanvil/feascan.c"

#line 1009 "fontanvil/feascan.c"

#define INITIAL 0
#define kw_allowed 1
#define hexint 2
#define tenths 3
#define in_string 4

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
#include <unistd.h>
#endif

#ifndef YY_EXTRA_TYPE
#define YY_EXTRA_TYPE void *
#endif

static int yy_init_globals ( void );

/* Accessor methods to globals.
   These are made visible to non-reentrant scanners for convenience. */

int yylex_destroy ( void );

int yyget_debug ( void );

void yyset_debug ( int debug_flag  );

YY_EXTRA_TYPE yyget_extra ( void );

void yyset_extra ( YY_EXTRA_TYPE user_defined  );

FILE *yyget_in ( void );

void yyset_in  ( FILE * _in_str  );

FILE *yyget_out ( void );

void yyset_out  ( FILE * _out_str  );

			int yyget_leng ( void );

char *yyget_text ( void );

int yyget_lineno ( void );

void yyset_lineno ( int _line_number  );

/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int yywrap ( void );
#else
extern int yywrap ( void );
#endif
#endif

#ifndef YY_NO_UNPUT
    
    static void yyunput ( int c, char *buf_ptr  );
    
#endif

#ifndef yytext_ptr
static void yy_flex_strncpy ( char *, const char *, int );
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen ( const char * );
#endif

#ifndef YY_NO_INPUT
#ifdef __cplusplus
static int yyinput ( void );
#else
static int input ( void );
#endif

#endif

/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k */
#define YY_READ_BUF_SIZE 16384
#else
#define YY_READ_BUF_SIZE 8192
#endif /* __ia64__ */
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO do { if (fwrite( yytext, (size_t) yyleng, 1, yyout )) {} } while (0)
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
	if ( YY_CURRENT_BUFFER_LVALUE->yy_is_interactive ) \
		{ \
		int c = '*'; \
		int n; \
		for ( n = 0; n < max_size && \
			     (c = getc( yyin )) != EOF && c != '\n'; ++n ) \
			buf[n] = (char) c; \
		if ( c == '\n' ) \
			buf[n++] = (char) c; \
		if ( c == EOF && ferror( yyin ) ) \
			YY_FATAL_ERROR( "input in flex scanner failed" ); \
		result = n; \
		} \
	else \
		{ \
		errno=0; \
		while ( (result = (int) fread(buf, 1, (yy_size_t) max_size, yyin)) == 0 && ferror(yyin)) \
			{ \
			if( errno != EINTR) \
				{ \
				YY_FATAL_ERROR( "input in flex scanner failed" ); \
				break; \
				} \
			errno=0; \
			clearerr(yyin); \
			} \
		}\
\

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
#define YY_FATAL_ERROR(msg) yy_fatal_error( msg )
#endif

/* end tables serialization structures and prototypes */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1

extern int yylex (void);

#define YY_DECL int yylex (void)
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after yytext and yyleng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK /*LINTED*/break;
#endif

#define YY_RULE_SETUP \
	YY_USER_ACTION

/** The main scanner function which does all the work.
 */
YY_DECL
{
	yy_state_type yy_current_state;
	char *yy_cp, *yy_bp;
	int yy_act;
    
	if ( !(yy_init) )
		{
		(yy_init) = 1;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

		if ( ! (yy_start) )
			(yy_start) = 1;	/* first start state */

		if ( ! yyin )
			yyin = stdin;

		if ( ! yyout )
			yyout = stdout;

		if ( ! YY_CURRENT_BUFFER ) {
			yyensure_buffer_stack ();
			YY_CURRENT_BUFFER_LVALUE =
				yy_create_buffer( yyin, YY_BUF_SIZE );
		}

		yy_load_buffer_state(  );
		}

	{
#line 55 "fontanvil/feascan.l"



#line 59 "fontanvil/feascan.l"
   char *string_in_progress;
   int string_buffer_size,string_buffer_ptr;
   
   if (tok->backedup) {
      tok->backedup=false;
      return;
   }

   yyin=NULL;
   gtok=tok;

   switch (tm) {
    case tm_nokw:
      BEGIN(INITIAL);
      break;
    case tm_hexint:
      BEGIN(hexint);
      break;
    case tm_tenths:
      BEGIN(tenths);
      break;
    case tm_string:
      BEGIN(in_string);
      string_in_progress=(char *)malloc(80);
      string_buffer_size=80;
      string_buffer_ptr=0;
      string_in_progress[0]='\0';
      break;
    case tm_generic:
    default:
      BEGIN(kw_allowed);
      break;
   }
   
   tok->could_be_tag=false;


#line 1272 "fontanvil/feascan.c"

	while ( /*CONSTCOND*/1 )		/* loops until end-of-file is reached */
		{
		yy_cp = (yy_c_buf_p);

		/* Support of yytext. */
		*yy_cp = (yy_hold_char);

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

		yy_current_state = (yy_start);
yy_match:
		do
			{
			YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)] ;
			if ( yy_accept[yy_current_state] )
				{
				(yy_last_accepting_state) = yy_current_state;
				(yy_last_accepting_cpos) = yy_cp;
				}
			while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
				{
				yy_current_state = (int) yy_def[yy_current_state];
				if ( yy_current_state >= 404 )
					yy_c = yy_meta[yy_c];
				}
			yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
			++yy_cp;
			}
		while ( yy_base[yy_current_state] != 531 );

yy_find_action:
		yy_act = yy_accept[yy_current_state];
		if ( yy_act == 0 )
			{ /* have to back up */
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			yy_act = yy_accept[yy_current_state];
			}

		YY_DO_BEFORE_ACTION;

do_action:	/* This label is used only to access EOF actions. */

		switch ( yy_act )
	{ /* beginning of action switch */
			case 0: /* must back up */
			/* undo the effects of YY_DO_BEFORE_ACTION */
			*yy_cp = (yy_hold_char);
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			goto yy_find_action;

case 1:
YY_RULE_SETUP
#line 96 "fontanvil/feascan.l"
{
   int i;
   uint32_t uval=0;

   if (string_buffer_ptr+5>=string_buffer_size) {
      string_buffer_size*=5;
      string_buffer_size/=4;
      string_in_progress=(char *)realloc(string_in_progress,
					 string_buffer_size);
   }

   for (i=1;i<yyleng;i++) {
      uval*=16;
      if ((yytext[i]>='0') && (yytext[i]<='9'))
	uval+=(yytext[i]-'0');
      else if ((yytext[i]>='A') && (yytext[i]<='F'))
	uval+=(yytext[i]-'A'+10);
      else
	uval+=(yytext[i]-'a'+10);
   }
   string_buffer_ptr=utf8_idpb(string_in_progress+string_buffer_ptr,uval,0)
     -string_in_progress;
   string_in_progress[string_buffer_ptr]='\0';
}
	YY_BREAK
case 2:
/* rule 2 can match eol */
YY_RULE_SETUP
#line 120 "fontanvil/feascan.l"
{ tok->line[tok->inc_depth]++; }
	YY_BREAK
case 3:
YY_RULE_SETUP
#line 121 "fontanvil/feascan.l"
{
   tok->nm=string_in_progress;
   BEGIN(INITIAL);
   return;
}
	YY_BREAK
case 4:
/* rule 4 can match eol */
YY_RULE_SETUP
#line 126 "fontanvil/feascan.l"
{
   int i;

   if (string_buffer_ptr+1>=string_buffer_size) {
      string_buffer_size*=5;
      string_buffer_size/=4;
      string_in_progress=(char *)realloc(string_in_progress,
					 string_buffer_size);
   }

   string_in_progress[string_buffer_ptr++]=yytext[yyleng-1];
   string_in_progress[string_buffer_ptr]='\0';
}
	YY_BREAK
case 5:
/* rule 5 can match eol */
YY_RULE_SETUP
#line 140 "fontanvil/feascan.l"
{ tok->line[tok->inc_depth]++; }
	YY_BREAK
case 6:
/* rule 6 can match eol */
YY_RULE_SETUP
#line 141 "fontanvil/feascan.l"
{ tok->line[tok->inc_depth]++; }
	YY_BREAK
case 7:
YY_RULE_SETUP
#line 142 "fontanvil/feascan.l"
/* skip whitespace */
	YY_BREAK
case YY_STATE_EOF(INITIAL):
case YY_STATE_EOF(kw_allowed):
case YY_STATE_EOF(hexint):
case YY_STATE_EOF(tenths):
case YY_STATE_EOF(in_string):
#line 144 "fontanvil/feascan.l"
{
   if (tok->inc_depth>0) {
      afclose(tok->inlist[tok->inc_depth]);
      free(tok->filename[tok->inc_depth]);
      yypop_buffer_state();
   } else {
      tok->type=tk_eof;
      strcpy(tok->tokbuf,"EOF");
      return;
   }
}
	YY_BREAK

case 8:
/* rule 8 can match eol */
YY_RULE_SETUP
#line 158 "fontanvil/feascan.l"
{
   char *cp=yytext+7,*fn,*fn2;
   AFILE *in;
   
   /* find and mark end of filename */
   while (*cp!='(') cp++;
   cp++;
   while ((*cp==' ') || (*cp=='\t')) cp++;
   fn=cp;
   while ((*cp!=' ') && (*cp!='\t') && (*cp!=')')) cp++;
   *cp='\0';
   
   do {
   
      if (tok->inc_depth>=MAXI-1) {
	 ErrorMsg(2,"Includes nested too deeply on line %d of %s\n",
		  tok->line[tok->inc_depth], tok->filename[tok->inc_depth]);
	 ++tok->err_count;
	 break;
      }
      
      if ((*fn=='/') ||
	  ((cp=strrchr(tok->filename[tok->inc_depth],'/'))==NULL))
	fn2=fastrdup(fn);
      else {
	 *cp='\0';
	 fn2=GFileAppendFile(tok->filename[tok->inc_depth],fn,false);
	 *cp='/';
      }
      
      in=afopen(fn2,"r");
      if (in==NULL) {
	 ErrorMsg(2,"Could not open include file (%s) on line %d of %s\n",
		  fn2,tok->line[tok->inc_depth],
		  tok->filename[tok->inc_depth]);
	 tok->err_count++;
	 free(fn2);
	 break;
      }
      
      tok->inc_depth++;
      tok->filename[tok->inc_depth]=fn2;
      tok->inlist[tok->inc_depth]=in;
      tok->line[tok->inc_depth]=1;

      yypush_buffer_state(yy_create_buffer(NULL,YY_BUF_SIZE));

   } while (0);
}
	YY_BREAK
case 9:
YY_RULE_SETUP
#line 208 "fontanvil/feascan.l"
{ tok->type=tk_anchor; return; }
	YY_BREAK
case 10:
YY_RULE_SETUP
#line 209 "fontanvil/feascan.l"
{ tok->type=tk_anonymous; return; }
	YY_BREAK
case 11:
YY_RULE_SETUP
#line 210 "fontanvil/feascan.l"
{ tok->type=tk_by; return; }
	YY_BREAK
case 12:
YY_RULE_SETUP
#line 211 "fontanvil/feascan.l"
{ tok->type=tk_caret; return; }
	YY_BREAK
case 13:
YY_RULE_SETUP
#line 212 "fontanvil/feascan.l"
{ tok->type=tk_cursive; return; }
	YY_BREAK
case 14:
YY_RULE_SETUP
#line 213 "fontanvil/feascan.l"
{ tok->type=tk_device; return; }
	YY_BREAK
case 15:
YY_RULE_SETUP
#line 214 "fontanvil/feascan.l"
{ tok->type=tk_enumerate; return; }
	YY_BREAK
case 16:
YY_RULE_SETUP
#line 215 "fontanvil/feascan.l"
{ tok->type=tk_excludeDFLT; return; }
	YY_BREAK
case 17:
YY_RULE_SETUP
#line 216 "fontanvil/feascan.l"
{ tok->type=tk_exclude_dflt; return; }
	YY_BREAK
case 18:
YY_RULE_SETUP
#line 217 "fontanvil/feascan.l"
{ tok->type=tk_feature; return; }
	YY_BREAK
case 19:
YY_RULE_SETUP
#line 218 "fontanvil/feascan.l"
{ tok->type=tk_from; return; }
	YY_BREAK
case 20:
YY_RULE_SETUP
#line 219 "fontanvil/feascan.l"
{ tok->type=tk_ignore; return; }
	YY_BREAK
case 21:
YY_RULE_SETUP
#line 220 "fontanvil/feascan.l"
{ tok->type=tk_IgnoreBaseGlyphs; return; }
	YY_BREAK
case 22:
YY_RULE_SETUP
#line 221 "fontanvil/feascan.l"
{ tok->type=tk_IgnoreLigatures; return; }
	YY_BREAK
case 23:
YY_RULE_SETUP
#line 222 "fontanvil/feascan.l"
{ tok->type=tk_IgnoreMarks; return; }
	YY_BREAK
case 24:
YY_RULE_SETUP
#line 223 "fontanvil/feascan.l"
{ tok->type=tk_includeDFLT; return; }
	YY_BREAK
case 25:
YY_RULE_SETUP
#line 224 "fontanvil/feascan.l"
{ tok->type=tk_include_dflt; return; }
	YY_BREAK
case 26:
YY_RULE_SETUP
#line 225 "fontanvil/feascan.l"
{ tok->type=tk_language; return; }
	YY_BREAK
case 27:
YY_RULE_SETUP
#line 226 "fontanvil/feascan.l"
{ tok->type=tk_languagesystem; return; }
	YY_BREAK
case 28:
YY_RULE_SETUP
#line 227 "fontanvil/feascan.l"
{ tok->type=tk_lookup; return; }
	YY_BREAK
case 29:
YY_RULE_SETUP
#line 228 "fontanvil/feascan.l"
{ tok->type=tk_lookupflag; return; }
	YY_BREAK
case 30:
YY_RULE_SETUP
#line 229 "fontanvil/feascan.l"
{ tok->type=tk_mark; return; }
	YY_BREAK
case 31:
YY_RULE_SETUP
#line 230 "fontanvil/feascan.l"
{ tok->type=tk_nameid; return; }
	YY_BREAK
case 32:
YY_RULE_SETUP
#line 231 "fontanvil/feascan.l"
{ tok->type=tk_NULL; return; }
	YY_BREAK
case 33:
YY_RULE_SETUP
#line 232 "fontanvil/feascan.l"
{ tok->type=tk_parameters; return; }
	YY_BREAK
case 34:
YY_RULE_SETUP
#line 233 "fontanvil/feascan.l"
{ tok->type=tk_position; return; }
	YY_BREAK
case 35:
YY_RULE_SETUP
#line 234 "fontanvil/feascan.l"
{ tok->type=tk_required; return; }
	YY_BREAK
case 36:
YY_RULE_SETUP
#line 235 "fontanvil/feascan.l"
{ tok->type=tk_RightToLeft; return; }
	YY_BREAK
case 37:
YY_RULE_SETUP
#line 236 "fontanvil/feascan.l"
{ tok->type=tk_script; return; }
	YY_BREAK
case 38:
YY_RULE_SETUP
#line 237 "fontanvil/feascan.l"
{ tok->type=tk_substitute; return; }
	YY_BREAK
case 39:
YY_RULE_SETUP
#line 238 "fontanvil/feascan.l"
{ tok->type=tk_subtable; return; }
	YY_BREAK
case 40:
YY_RULE_SETUP
#line 239 "fontanvil/feascan.l"
{ tok->type=tk_table; return; }
	YY_BREAK
case 41:
YY_RULE_SETUP
#line 240 "fontanvil/feascan.l"
{ tok->type=tk_useExtension; return; }
	YY_BREAK
case 42:
YY_RULE_SETUP
#line 242 "fontanvil/feascan.l"
{ tok->type=tk_anchorDef; return; }
	YY_BREAK
case 43:
YY_RULE_SETUP
#line 243 "fontanvil/feascan.l"
{ tok->type=tk_valueRecordDef; return; }
	YY_BREAK
case 44:
YY_RULE_SETUP
#line 244 "fontanvil/feascan.l"
{ tok->type=tk_contourpoint; return; }
	YY_BREAK
case 45:
YY_RULE_SETUP
#line 245 "fontanvil/feascan.l"
{ tok->type=tk_MarkAttachmentType; return; }
	YY_BREAK
case 46:
YY_RULE_SETUP
#line 246 "fontanvil/feascan.l"
{ tok->type=tk_UseMarkFilteringSet; return; }
	YY_BREAK
case 47:
YY_RULE_SETUP
#line 247 "fontanvil/feascan.l"
{ tok->type=tk_reversesub; return; }
	YY_BREAK
case 48:
YY_RULE_SETUP
#line 248 "fontanvil/feascan.l"
{ tok->type=tk_markClass; return; }
	YY_BREAK
case 49:
YY_RULE_SETUP
#line 249 "fontanvil/feascan.l"
{ tok->type=tk_base; return; }
	YY_BREAK
case 50:
YY_RULE_SETUP
#line 250 "fontanvil/feascan.l"
{ tok->type=tk_ligature; return; }
	YY_BREAK
case 51:
YY_RULE_SETUP
#line 251 "fontanvil/feascan.l"
{ tok->type=tk_ligComponent; return; }
	YY_BREAK
case 52:
YY_RULE_SETUP
#line 252 "fontanvil/feascan.l"
{ tok->type=tk_featureNames; return; }
	YY_BREAK
case 53:
YY_RULE_SETUP
#line 254 "fontanvil/feascan.l"
{ tok->type=tk_substitute; return; }
	YY_BREAK
case 54:
YY_RULE_SETUP
#line 255 "fontanvil/feascan.l"
{ tok->type=tk_position; return; }
	YY_BREAK
case 55:
YY_RULE_SETUP
#line 256 "fontanvil/feascan.l"
{ tok->type=tk_reversesub; return; }
	YY_BREAK
case 56:
YY_RULE_SETUP
#line 257 "fontanvil/feascan.l"
{ tok->type=tk_enumerate; return; }
	YY_BREAK
case 57:
YY_RULE_SETUP
#line 258 "fontanvil/feascan.l"
{ tok->type=tk_anonymous; return; }
	YY_BREAK

case 58:
YY_RULE_SETUP
#line 262 "fontanvil/feascan.l"
{
   char *buf;
   
   buf=(char *)malloc(yyleng+1);
   memcpy(buf,yytext,yyleng);
   buf[yyleng]='\0';
   if (yytext[0]=='\\') {
      tok->type=tk_cid;
      tok->value=strtol(buf+1,NULL,0);
   } else {
      tok->type=tk_int;
      tok->value=strtol(buf,NULL,0);
   }
   free(buf);
   return;
}
	YY_BREAK
case 59:
YY_RULE_SETUP
#line 279 "fontanvil/feascan.l"
{
   char *buf;
   
   buf=(char *)malloc(yyleng+1);
   memcpy(buf,yytext,yyleng);
   buf[yyleng]='\0';
   tok->type=tk_int;
   tok->value=rint(strtod(buf,NULL)*10);
   free(buf);
   return;
}
	YY_BREAK
case 60:
YY_RULE_SETUP
#line 291 "fontanvil/feascan.l"
{
   char *buf;

   buf=(char *)malloc(yyleng+1);
   memcpy(buf,yytext,yyleng);
   buf[yyleng]='\0';
   if (yytext[0]=='\\') {
      tok->type=tk_cid;
      tok->value=strtol(buf+1,NULL,10);
   } else {
      tok->type=tk_int;
      tok->value=strtol(buf,NULL,10);
   }
   free(buf);
   return;
}
	YY_BREAK
case 61:
YY_RULE_SETUP
#line 308 "fontanvil/feascan.l"
{
   int start=0;
   
   tok->type=tk_name;
   if (yytext[0]=='@') {
      tok->type=tk_class;
      start=1;
   } else if (yytext[0]=='\\')
	start=1;
   strncpy(tok->tokbuf,yytext+start,yyleng-start>MAXT?MAXT+1:yyleng-start+1);
   tok->tokbuf[MAXT]='\0';

   if (yyleng>31+start) {
      /* Adobe says glyphnames are 31 chars, but Mangal uses longer names */
      ErrorMsg(2,"Name, %s%s, too long on line %d of %s\n",
	       tok->tokbuf, yyleng-start>MAXT? "..." : "",
	       tok->line[tok->inc_depth], tok->filename[tok->inc_depth]);
      if (yyleng-start>MAXT)
	tok->err_count++;

   } else if (yyleng==start) {
      ErrorMsg(2,"Missing name on line %d of %s\n",
	       tok->line[tok->inc_depth], tok->filename[tok->inc_depth]);
      tok->err_count++;

   } else {
      if ((tok->type==tk_name) && (yyleng<=4)) {
	 tok->could_be_tag=true;
	 switch (yyleng) {
	  case 4:
	    tok->tag=(yytext[0]<<24)|(yytext[1]<<16)|(yytext[2]<<8)|yytext[3];
	    break;
	  case 3:
	    tok->tag=(yytext[0]<<24)|(yytext[1]<<16)|(yytext[2]<<8)|0x20;
	    break;
	  case 2:
	    tok->tag=(yytext[0]<<24)|(yytext[1]<<16)|0x2020;
	    break;
	  case 1:
	  default:
	    tok->tag=(yytext[0]<<24)|0x202020;
	    break;
	 }
      }
      return;
   }
}
	YY_BREAK
case 62:
YY_RULE_SETUP
#line 356 "fontanvil/feascan.l"
{
   tok->type=tk_char;
   tok->tokbuf[0]=yytext[0];
   tok->tokbuf[1]='\0';
   return;
}
	YY_BREAK
case 63:
YY_RULE_SETUP
#line 363 "fontanvil/feascan.l"
{
   if (!tok->skipping) {
      ErrorMsg(2,"Unexpected character (0x%02X) on line %d of %s\n",
	       yytext[0],
	       tok->line[tok->inc_depth],
	       tok->filename[tok->inc_depth]);
      ++tok->err_count;
   }
}
	YY_BREAK
case 64:
YY_RULE_SETUP
#line 372 "fontanvil/feascan.l"
YY_FATAL_ERROR( "flex scanner jammed" );
	YY_BREAK
#line 1860 "fontanvil/feascan.c"

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - (yytext_ptr)) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = (yy_hold_char);
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed yyin at a new source and called
			 * yylex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
			YY_CURRENT_BUFFER_LVALUE->yy_input_file = yyin;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( (yy_c_buf_p) <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			(yy_c_buf_p) = (yytext_ptr) + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state(  );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state );

			yy_bp = (yytext_ptr) + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++(yy_c_buf_p);
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
				yy_cp = (yy_c_buf_p);
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer(  ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				(yy_did_buffer_switch_on_eof) = 0;

				if ( yywrap(  ) )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * yytext, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					(yy_c_buf_p) = (yytext_ptr) + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				(yy_c_buf_p) =
					(yytext_ptr) + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				(yy_c_buf_p) =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)];

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
	} /* end of user's declarations */
} /* end of yylex */

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
static int yy_get_next_buffer (void)
{
    	char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
	char *source = (yytext_ptr);
	int number_to_move, i;
	int ret_val;

	if ( (yy_c_buf_p) > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( (yy_c_buf_p) - (yytext_ptr) - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (int) ((yy_c_buf_p) - (yytext_ptr) - 1);

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars) = 0;

	else
		{
			int num_to_read =
			YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			/* just a shorter name for the current buffer */
			YY_BUFFER_STATE b = YY_CURRENT_BUFFER_LVALUE;

			int yy_c_buf_p_offset =
				(int) ((yy_c_buf_p) - b->yy_ch_buf);

			if ( b->yy_is_our_buffer )
				{
				int new_size = b->yy_buf_size * 2;

				if ( new_size <= 0 )
					b->yy_buf_size += b->yy_buf_size / 8;
				else
					b->yy_buf_size *= 2;

				b->yy_ch_buf = (char *)
					/* Include room in for 2 EOB chars. */
					yyrealloc( (void *) b->yy_ch_buf,
							 (yy_size_t) (b->yy_buf_size + 2)  );
				}
			else
				/* Can't grow it, we don't own it. */
				b->yy_ch_buf = NULL;

			if ( ! b->yy_ch_buf )
				YY_FATAL_ERROR(
				"fatal error - scanner input buffer overflow" );

			(yy_c_buf_p) = &b->yy_ch_buf[yy_c_buf_p_offset];

			num_to_read = YY_CURRENT_BUFFER_LVALUE->yy_buf_size -
						number_to_move - 1;

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
			(yy_n_chars), num_to_read );

		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	if ( (yy_n_chars) == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			yyrestart( yyin  );
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	if (((yy_n_chars) + number_to_move) > YY_CURRENT_BUFFER_LVALUE->yy_buf_size) {
		/* Extend the array by 50%, plus the number we really need. */
		int new_size = (yy_n_chars) + number_to_move + ((yy_n_chars) >> 1);
		YY_CURRENT_BUFFER_LVALUE->yy_ch_buf = (char *) yyrealloc(
			(void *) YY_CURRENT_BUFFER_LVALUE->yy_ch_buf, (yy_size_t) new_size  );
		if ( ! YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			YY_FATAL_ERROR( "out of dynamic memory in yy_get_next_buffer()" );
		/* "- 2" to take care of EOB's */
		YY_CURRENT_BUFFER_LVALUE->yy_buf_size = (int) (new_size - 2);
	}

	(yy_n_chars) += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] = YY_END_OF_BUFFER_CHAR;

	(yytext_ptr) = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

	return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

    static yy_state_type yy_get_previous_state (void)
{
	yy_state_type yy_current_state;
	char *yy_cp;
    
	yy_current_state = (yy_start);

	for ( yy_cp = (yytext_ptr) + YY_MORE_ADJ; yy_cp < (yy_c_buf_p); ++yy_cp )
		{
		YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 1);
		if ( yy_accept[yy_current_state] )
			{
			(yy_last_accepting_state) = yy_current_state;
			(yy_last_accepting_cpos) = yy_cp;
			}
		while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
			{
			yy_current_state = (int) yy_def[yy_current_state];
			if ( yy_current_state >= 404 )
				yy_c = yy_meta[yy_c];
			}
		yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
		}

	return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */
    static yy_state_type yy_try_NUL_trans  (yy_state_type yy_current_state )
{
	int yy_is_jam;
    	char *yy_cp = (yy_c_buf_p);

	YY_CHAR yy_c = 1;
	if ( yy_accept[yy_current_state] )
		{
		(yy_last_accepting_state) = yy_current_state;
		(yy_last_accepting_cpos) = yy_cp;
		}
	while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
		{
		yy_current_state = (int) yy_def[yy_current_state];
		if ( yy_current_state >= 404 )
			yy_c = yy_meta[yy_c];
		}
	yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
	yy_is_jam = (yy_current_state == 403);

		return yy_is_jam ? 0 : yy_current_state;
}

#ifndef YY_NO_UNPUT

    static void yyunput (int c, char * yy_bp )
{
	char *yy_cp;
    
    yy_cp = (yy_c_buf_p);

	/* undo effects of setting up yytext */
	*yy_cp = (yy_hold_char);

	if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
		{ /* need to shift things up to make room */
		/* +2 for EOB chars. */
		int number_to_move = (yy_n_chars) + 2;
		char *dest = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[
					YY_CURRENT_BUFFER_LVALUE->yy_buf_size + 2];
		char *source =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move];

		while ( source > YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			*--dest = *--source;

		yy_cp += (int) (dest - source);
		yy_bp += (int) (dest - source);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars =
			(yy_n_chars) = (int) YY_CURRENT_BUFFER_LVALUE->yy_buf_size;

		if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
			YY_FATAL_ERROR( "flex scanner push-back overflow" );
		}

	*--yy_cp = (char) c;

	(yytext_ptr) = yy_bp;
	(yy_hold_char) = *yy_cp;
	(yy_c_buf_p) = yy_cp;
}

#endif

#ifndef YY_NO_INPUT
#ifdef __cplusplus
    static int yyinput (void)
#else
    static int input  (void)
#endif

{
	int c;
    
	*(yy_c_buf_p) = (yy_hold_char);

	if ( *(yy_c_buf_p) == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( (yy_c_buf_p) < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			/* This was really a NUL. */
			*(yy_c_buf_p) = '\0';

		else
			{ /* need more input */
			int offset = (int) ((yy_c_buf_p) - (yytext_ptr));
			++(yy_c_buf_p);

			switch ( yy_get_next_buffer(  ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					yyrestart( yyin );

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( yywrap(  ) )
						return 0;

					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput();
#else
					return input();
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					(yy_c_buf_p) = (yytext_ptr) + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) (yy_c_buf_p);	/* cast for 8-bit char's */
	*(yy_c_buf_p) = '\0';	/* preserve yytext */
	(yy_hold_char) = *++(yy_c_buf_p);

	return c;
}
#endif	/* ifndef YY_NO_INPUT */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * 
 * @note This function does not reset the start condition to @c INITIAL .
 */
    void yyrestart  (FILE * input_file )
{
    
	if ( ! YY_CURRENT_BUFFER ){
        yyensure_buffer_stack ();
		YY_CURRENT_BUFFER_LVALUE =
            yy_create_buffer( yyin, YY_BUF_SIZE );
	}

	yy_init_buffer( YY_CURRENT_BUFFER, input_file );
	yy_load_buffer_state(  );
}

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * 
 */
    void yy_switch_to_buffer  (YY_BUFFER_STATE  new_buffer )
{
    
	/* TODO. We should be able to replace this entire function body
	 * with
	 *		yypop_buffer_state();
	 *		yypush_buffer_state(new_buffer);
     */
	yyensure_buffer_stack ();
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	yy_load_buffer_state(  );

	/* We don't actually know whether we did this switch during
	 * EOF (yywrap()) processing, but the only time this flag
	 * is looked at is after yywrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	(yy_did_buffer_switch_on_eof) = 1;
}

static void yy_load_buffer_state  (void)
{
    	(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
	(yytext_ptr) = (yy_c_buf_p) = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
	yyin = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
	(yy_hold_char) = *(yy_c_buf_p);
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * 
 * @return the allocated buffer state.
 */
    YY_BUFFER_STATE yy_create_buffer  (FILE * file, int  size )
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) yyalloc( sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_buf_size = size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) yyalloc( (yy_size_t) (b->yy_buf_size + 2)  );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_is_our_buffer = 1;

	yy_init_buffer( b, file );

	return b;
}

/** Destroy the buffer.
 * @param b a buffer created with yy_create_buffer()
 * 
 */
    void yy_delete_buffer (YY_BUFFER_STATE  b )
{
    
	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		yyfree( (void *) b->yy_ch_buf  );

	yyfree( (void *) b  );
}

/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a yyrestart() or at EOF.
 */
    static void yy_init_buffer  (YY_BUFFER_STATE  b, FILE * file )

{
	int oerrno = errno;
    
	yy_flush_buffer( b );

	b->yy_input_file = file;
	b->yy_fill_buffer = 1;

    /* If b is the current buffer, then yy_init_buffer was _probably_
     * called from yyrestart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

        b->yy_is_interactive = file ? (isatty( fileno(file) ) > 0) : 0;
    
	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * 
 */
    void yy_flush_buffer (YY_BUFFER_STATE  b )
{
    	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		yy_load_buffer_state(  );
}

/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  
 */
void yypush_buffer_state (YY_BUFFER_STATE new_buffer )
{
    	if (new_buffer == NULL)
		return;

	yyensure_buffer_stack();

	/* This block is copied from yy_switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		(yy_buffer_stack_top)++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from yy_switch_to_buffer. */
	yy_load_buffer_state(  );
	(yy_did_buffer_switch_on_eof) = 1;
}

/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  
 */
void yypop_buffer_state (void)
{
    	if (!YY_CURRENT_BUFFER)
		return;

	yy_delete_buffer(YY_CURRENT_BUFFER );
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if ((yy_buffer_stack_top) > 0)
		--(yy_buffer_stack_top);

	if (YY_CURRENT_BUFFER) {
		yy_load_buffer_state(  );
		(yy_did_buffer_switch_on_eof) = 1;
	}
}

/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
static void yyensure_buffer_stack (void)
{
	yy_size_t num_to_alloc;
    
	if (!(yy_buffer_stack)) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
      num_to_alloc = 1; /* After all that talk, this was set to 1 anyways... */
		(yy_buffer_stack) = (struct yy_buffer_state**)yyalloc
								(num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		memset((yy_buffer_stack), 0, num_to_alloc * sizeof(struct yy_buffer_state*));

		(yy_buffer_stack_max) = num_to_alloc;
		(yy_buffer_stack_top) = 0;
		return;
	}

	if ((yy_buffer_stack_top) >= ((yy_buffer_stack_max)) - 1){

		/* Increase the buffer to prepare for a possible push. */
		yy_size_t grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = (yy_buffer_stack_max) + grow_size;
		(yy_buffer_stack) = (struct yy_buffer_state**)yyrealloc
								((yy_buffer_stack),
								num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		/* zero only the new slots.*/
		memset((yy_buffer_stack) + (yy_buffer_stack_max), 0, grow_size * sizeof(struct yy_buffer_state*));
		(yy_buffer_stack_max) = num_to_alloc;
	}
}

/** Setup the input buffer state to scan directly from a user-specified character buffer.
 * @param base the character buffer
 * @param size the size in bytes of the character buffer
 * 
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_buffer  (char * base, yy_size_t  size )
{
	YY_BUFFER_STATE b;
    
	if ( size < 2 ||
	     base[size-2] != YY_END_OF_BUFFER_CHAR ||
	     base[size-1] != YY_END_OF_BUFFER_CHAR )
		/* They forgot to leave room for the EOB's. */
		return NULL;

	b = (YY_BUFFER_STATE) yyalloc( sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_buffer()" );

	b->yy_buf_size = (int) (size - 2);	/* "- 2" to take care of EOB's */
	b->yy_buf_pos = b->yy_ch_buf = base;
	b->yy_is_our_buffer = 0;
	b->yy_input_file = NULL;
	b->yy_n_chars = b->yy_buf_size;
	b->yy_is_interactive = 0;
	b->yy_at_bol = 1;
	b->yy_fill_buffer = 0;
	b->yy_buffer_status = YY_BUFFER_NEW;

	yy_switch_to_buffer( b  );

	return b;
}

/** Setup the input buffer state to scan a string. The next call to yylex() will
 * scan from a @e copy of @a str.
 * @param yystr a NUL-terminated string to scan
 * 
 * @return the newly allocated buffer state object.
 * @note If you want to scan bytes that may contain NUL values, then use
 *       yy_scan_bytes() instead.
 */
YY_BUFFER_STATE yy_scan_string (const char * yystr )
{
    
	return yy_scan_bytes( yystr, (int) strlen(yystr) );
}

/** Setup the input buffer state to scan the given bytes. The next call to yylex() will
 * scan from a @e copy of @a bytes.
 * @param yybytes the byte buffer to scan
 * @param _yybytes_len the number of bytes in the buffer pointed to by @a bytes.
 * 
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_bytes  (const char * yybytes, int  _yybytes_len )
{
	YY_BUFFER_STATE b;
	char *buf;
	yy_size_t n;
	int i;
    
	/* Get memory for full buffer, including space for trailing EOB's. */
	n = (yy_size_t) (_yybytes_len + 2);
	buf = (char *) yyalloc( n  );
	if ( ! buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_bytes()" );

	for ( i = 0; i < _yybytes_len; ++i )
		buf[i] = yybytes[i];

	buf[_yybytes_len] = buf[_yybytes_len+1] = YY_END_OF_BUFFER_CHAR;

	b = yy_scan_buffer( buf, n );
	if ( ! b )
		YY_FATAL_ERROR( "bad buffer in yy_scan_bytes()" );

	/* It's okay to grow etc. this buffer, and we should throw it
	 * away when we're done.
	 */
	b->yy_is_our_buffer = 1;

	return b;
}

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

static void yynoreturn yy_fatal_error (const char* msg )
{
			fprintf( stderr, "%s\n", msg );
	exit( YY_EXIT_FAILURE );
}

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		yytext[yyleng] = (yy_hold_char); \
		(yy_c_buf_p) = yytext + yyless_macro_arg; \
		(yy_hold_char) = *(yy_c_buf_p); \
		*(yy_c_buf_p) = '\0'; \
		yyleng = yyless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/** Get the current line number.
 * 
 */
int yyget_lineno  (void)
{
    
    return yylineno;
}

/** Get the input stream.
 * 
 */
FILE *yyget_in  (void)
{
        return yyin;
}

/** Get the output stream.
 * 
 */
FILE *yyget_out  (void)
{
        return yyout;
}

/** Get the length of the current token.
 * 
 */
int yyget_leng  (void)
{
        return yyleng;
}

/** Get the current token.
 * 
 */

char *yyget_text  (void)
{
        return yytext;
}

/** Set the current line number.
 * @param _line_number line number
 * 
 */
void yyset_lineno (int  _line_number )
{
    
    yylineno = _line_number;
}

/** Set the input stream. This does not discard the current
 * input buffer.
 * @param _in_str A readable stream.
 * 
 * @see yy_switch_to_buffer
 */
void yyset_in (FILE *  _in_str )
{
        yyin = _in_str ;
}

void yyset_out (FILE *  _out_str )
{
        yyout = _out_str ;
}

int yyget_debug  (void)
{
        return yy_flex_debug;
}

void yyset_debug (int  _bdebug )
{
        yy_flex_debug = _bdebug ;
}

static int yy_init_globals (void)
{
        /* Initialization is the same as for the non-reentrant scanner.
     * This function is called from yylex_destroy(), so don't allocate here.
     */

    (yy_buffer_stack) = NULL;
    (yy_buffer_stack_top) = 0;
    (yy_buffer_stack_max) = 0;
    (yy_c_buf_p) = NULL;
    (yy_init) = 0;
    (yy_start) = 0;

/* Defined in main.c */
#ifdef YY_STDINIT
    yyin = stdin;
    yyout = stdout;
#else
    yyin = NULL;
    yyout = NULL;
#endif

    /* For future reference: Set errno on error, since we are called by
     * yylex_init()
     */
    return 0;
}

/* yylex_destroy is for both reentrant and non-reentrant scanners. */
int yylex_destroy  (void)
{
    
    /* Pop the buffer stack, destroying each element. */
	while(YY_CURRENT_BUFFER){
		yy_delete_buffer( YY_CURRENT_BUFFER  );
		YY_CURRENT_BUFFER_LVALUE = NULL;
		yypop_buffer_state();
	}

	/* Destroy the stack itself. */
	yyfree((yy_buffer_stack) );
	(yy_buffer_stack) = NULL;

    /* Reset the globals. This is important in a non-reentrant scanner so the next time
     * yylex() is called, initialization will occur. */
    yy_init_globals( );

    return 0;
}

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, const char * s2, int n )
{
		
	int i;
	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (const char * s )
{
	int n;
	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

void *yyalloc (yy_size_t  size )
{
			return malloc(size);
}

void *yyrealloc  (void * ptr, yy_size_t  size )
{
		
	/* The cast to (char *) in the following accommodates both
	 * implementations that use char* generic pointers, and those
	 * that use void* generic pointers.  It works with the latter
	 * because both ANSI C and C++ allow castless assignment from
	 * any pointer type to void*, and deal with argument conversions
	 * as though doing an assignment.
	 */
	return realloc(ptr, size);
}

void yyfree (void * ptr )
{
			free( (char *) ptr );	/* see yyrealloc() for (char *) cast */
}

#define YYTABLES_NAME "yytables"

#line 372 "fontanvil/feascan.l"
